from .trimap_ import TRIMAP

import pkg_resources
__version__ = pkg_resources.get_distribution('trimap').version
